Enum Syscall
Source pub enum Syscall {
Show 97 variants
Invalid = 0,
Getcwd = 17,
Eventfd2 = 19,
EpollCtl = 21,
EpollPwait = 22,
EpollCreate1 = 20,
Flock = 32,
Dup = 23,
Dup3 = 24,
Fcntl = 25,
Ioctl = 29,
MkdirAt = 34,
UnlinkAt = 35,
Ftruncate = 46,
Fallocate = 47,
LinkAt = 37,
FaccessAt = 48,
Chdir = 49,
Fchmod = 52,
OpenAt = 56,
Close = 57,
Pipe2 = 59,
GetDents64 = 61,
Lseek = 62,
Read = 63,
Write = 64,
Readv = 65,
Writev = 66,
Pread64 = 67,
Pwrite64 = 68,
Pselect6 = 72,
Ppoll = 73,
NewFstAtAt = 79,
NewFstat = 80,
ReadLinkAt = 78,
Fsync = 82,
Exit = 93,
ExitGroup = 94,
SetTidAddress = 96,
Futex = 98,
SetRobustList = 99,
Nanosleep = 101,
TimerCreate = 107,
TimerGettime = 108,
TimerGetoverrun = 109,
TimerSettime = 110,
TimerDelete = 111,
ClockGettime = 113,
ClockGetres = 114,
RtSigaction = 134,
RtSigprocmask = 135,
SetGid = 144,
SetUid = 146,
SetPgid = 154,
GetPgid = 155,
Uname = 160,
Umask = 166,
Prctl = 167,
GetPid = 172,
GetPpid = 173,
GetUid = 174,
GetEuid = 175,
GetGid = 176,
GetEgid = 177,
GetTid = 178,
Kill = 129,
Tkill = 130,
Brk = 214,
Munmap = 215,
Clone = 220,
Execve = 221,
Mmap = 222,
Mprotect = 226,
EpollWait = 232,
Getrandom = 278,
MemfdCreate = 279,
Wait4 = 260,
Prlimit64 = 261,
Socket = 198,
Socketpair = 199,
Bind = 200,
Listen = 201,
Accept = 202,
Connect = 203,
GetSockname = 204,
GetPeerName = 205,
Sendto = 206,
Recvfrom = 207,
SetSockopt = 208,
GetSockopt = 209,
Shutdown = 210,
Sendmsg = 211,
Recvmsg = 212,
Statx = 291,
RenameAt2 = 276,
Membarrier = 283,
FaccessAt2 = 439,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.